@@ -12,6 +12,7 @@ from snowflake.sqlalchemy import URL as snowflake_URL
 from sqlalchemy import create_engine
 from sqlalchemy.engine.base import Engine
 from yaml.loader import SafeLoader
+import pygsheets
 
 
 def postgres_engine_factory(args: Dict[str, str]) -> Engine:
@@ -372,3 +373,32 @@ def append_to_xcom_file(xcom_json: Dict[Any, Any]) -> None:
     except json.JSONDecodeError:
         pass  # the file is likely empty
     push_to_xcom_file({**existing_json, **xcom_json})
+
+
+def write_to_gsheets(
+    spreadsheet_id: str,
+    sheet_name: str,
+    data_df: pd.DataFrame,
+    service_account_credentials: str = "GSHEETS_SERVICE_ACCOUNT_CREDENTIALS",
+) -> None:
+    """
+    Gets a dataframe as a parameter and writes it under spreadsheet_id
+    and sheet_name using a Google Service Account stored under service_file_path.
+    Locally you should run it with your own Google credentials.
+    The Google Sheet must be shared with the account used to write into it.
+    """
+    gsheets = pygsheets.authorize(service_account_env_var=service_account_credentials)
+    sheet = gsheets.open_by_key(spreadsheet_id)
+
+    logging.basicConfig(stream=sys.stdout, level=20)
+
+    try:
+        logging.info(f"Writing data to sheet {sheet_name}...")
+        sheet.add_worksheet(sheet_name)
+        logging.info(f"Writing completed.")
+    except:
+        pass
+    wks_write = sheet.worksheet_by_title(sheet_name)
+    wks_write.clear("A1", None, "*")
+    wks_write.set_dataframe(data_df, (1, 1), encoding="utf-8", fit=True)
+    wks_write.frozen_rows = 1
